FlutterDeviceStatePlatform class abstract

Platform interface for Flutter Device State plugin

This is kept for potential future features that need platform-specific implementations. Currently, VPN and Security features use their own platform channels.

Inheritance
  • Object
  • PlatformInterface
  • FlutterDeviceStatePlatform
Implementers

Constructors

FlutterDeviceStatePlatform()
Constructs a FlutterDeviceStatePlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
Get platform version (example method, not currently used)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlutterDeviceStatePlatform
The default instance of FlutterDeviceStatePlatform to use.
getter/setter pair